@@ -269,7 +269,7 @@ fn register_rust_helpers(handlebars: &mut Handlebars<'_>) {
 fn register_script_helpers(handlebars: &mut Handlebars<'_>, helpers: &Helpers) {
     debug!("Registering script helpers...");
     for (helper_name, helper_path) in helpers {
-        if let Err(e) = handlebars.register_script_helper_file(&helper_name, &helper_path) {
+        if let Err(e) = handlebars.register_script_helper_file(helper_name, &helper_path) {
             warn!(
                 "Coudln't register helper script {} at path {:?} because {}",
                 helper_name, helper_path, e
